@@ -26,14 +26,10 @@ import mock
 
 import libcloud.utils.files
 
-from libcloud.utils.py3 import PY3
 from libcloud.utils.py3 import b
 from libcloud.utils.py3 import httplib
 from libcloud.utils.py3 import urlquote
 
-if PY3:
-    from io import FileIO as file
-
 from libcloud.common.types import LibcloudError, MalformedResponseError
 from libcloud.storage.base import Container, Object
 from libcloud.storage.types import ContainerAlreadyExistsError
@@ -43,25 +39,31 @@ from libcloud.storage.types import ObjectDoesNotExistError
 from libcloud.storage.types import ObjectHashMismatchError
 from libcloud.storage.types import InvalidContainerNameError
 from libcloud.storage.drivers.cloudfiles import CloudFilesStorageDriver
+from libcloud.storage.drivers.cloudfiles import CloudFilesUSStorageDriver
+from libcloud.storage.drivers.cloudfiles import CloudFilesUKStorageDriver
 from libcloud.storage.drivers.dummy import DummyIterator
 
-from libcloud.test import StorageMockHttp, MockRawResponse # pylint: disable-msg=E0611
-from libcloud.test import MockHttpTestCase # pylint: disable-msg=E0611
-from libcloud.test.file_fixtures import StorageFileFixtures, OpenStackFixtures # pylint: disable-msg=E0611
-
-current_hash = None
+from libcloud.test import StorageMockHttp, MockRawResponse  # pylint: disable-msg=E0611
+from libcloud.test import MockHttpTestCase  # pylint: disable-msg=E0611
+from libcloud.test.file_fixtures import StorageFileFixtures  # pylint: disable-msg=E0611
 
 
 class CloudFilesTests(unittest.TestCase):
+    driver_klass = CloudFilesStorageDriver
+    driver_args = ('dummy', 'dummy')
+    driver_kwargs = {}
+    region = 'ord'
 
     def setUp(self):
-        CloudFilesStorageDriver.connectionCls.conn_classes = (
+        self.driver_klass.connectionCls.conn_classes = (
             None, CloudFilesMockHttp)
-        CloudFilesStorageDriver.connectionCls.rawResponseCls = \
-                                              CloudFilesMockRawResponse
+        self.driver_klass.connectionCls.rawResponseCls = \
+            CloudFilesMockRawResponse
         CloudFilesMockHttp.type = None
         CloudFilesMockRawResponse.type = None
-        self.driver = CloudFilesStorageDriver('dummy', 'dummy')
+        self.driver = self.driver_klass(*self.driver_args,
+                                        **self.driver_kwargs)
+
         # normally authentication happens lazily, but we force it here
         self.driver.connection._populate_hosts_and_request_paths()
         self._remove_test_file()
@@ -69,6 +71,23 @@ class CloudFilesTests(unittest.TestCase):
     def tearDown(self):
         self._remove_test_file()
 
+    def test_invalid_ex_force_service_region(self):
+        driver = CloudFilesStorageDriver('driver', 'dummy',
+                                         ex_force_service_region='invalid')
+
+        try:
+            driver.list_containers()
+        except:
+            e = sys.exc_info()[1]
+            self.assertEqual(e.value, 'Could not find specified endpoint')
+        else:
+            self.fail('Exception was not thrown')
+
+    def test_ex_force_service_region(self):
+        driver = CloudFilesStorageDriver('driver', 'dummy',
+                                         ex_force_service_region='ORD')
+        driver.list_containers()
+
     def test_force_auth_token_kwargs(self):
         base_url = 'https://cdn2.clouddrive.com/v1/MossoCloudFS'
         kwargs = {
@@ -78,29 +97,12 @@ class CloudFilesTests(unittest.TestCase):
         driver = CloudFilesStorageDriver('driver', 'dummy', **kwargs)
         driver.list_containers()
 
-        self.assertEquals(kwargs['ex_force_auth_token'],
-            driver.connection.auth_token)
-        self.assertEquals('cdn2.clouddrive.com',
-            driver.connection.host)
-        self.assertEquals('/v1/MossoCloudFS',
-            driver.connection.request_path)
-
-    def test_invalid_ex_force_service_region(self):
-        driver = CloudFilesStorageDriver('driver', 'dummy',
-                ex_force_service_region='invalid')
-
-        try:
-            driver.list_containers()
-        except:
-            e = sys.exc_info()[1]
-            self.assertEquals(e.value, 'Could not find specified endpoint')
-        else:
-            self.fail('Exception was not thrown')
-
-    def test_ex_force_service_region(self):
-        driver = CloudFilesStorageDriver('driver', 'dummy',
-                ex_force_service_region='ORD')
-        driver.list_containers()
+        self.assertEqual(kwargs['ex_force_auth_token'],
+                         driver.connection.auth_token)
+        self.assertEqual('cdn2.clouddrive.com',
+                         driver.connection.host)
+        self.assertEqual('/v1/MossoCloudFS',
+                         driver.connection.request_path)
 
     def test_force_auth_url_kwargs(self):
         kwargs = {
@@ -109,10 +111,10 @@ class CloudFilesTests(unittest.TestCase):
         }
         driver = CloudFilesStorageDriver('driver', 'dummy', **kwargs)
 
-        self.assertEquals(kwargs['ex_force_auth_url'],
-            driver.connection._ex_force_auth_url)
-        self.assertEquals(kwargs['ex_force_auth_version'],
-            driver.connection._auth_version)
+        self.assertEqual(kwargs['ex_force_auth_url'],
+                         driver.connection._ex_force_auth_url)
+        self.assertEqual(kwargs['ex_force_auth_version'],
+                         driver.connection._auth_version)
 
     def test_invalid_json_throws_exception(self):
         CloudFilesMockHttp.type = 'MALFORMED_JSON'
@@ -124,14 +126,16 @@ class CloudFilesTests(unittest.TestCase):
             self.fail('Exception was not thrown')
 
     def test_service_catalog(self):
+        url = 'https://storage4.%s1.clouddrive.com/v1/MossoCloudFS' % \
+              (self.region)
         self.assertEqual(
-             'https://storage101.ord1.clouddrive.com/v1/MossoCloudFS',
-             self.driver.connection.get_endpoint())
+            url,
+            self.driver.connection.get_endpoint())
 
         self.driver.connection.cdn_request = True
         self.assertEqual(
-             'https://cdn2.clouddrive.com/v1/MossoCloudFS',
-             self.driver.connection.get_endpoint())
+            'https://cdn.clouddrive.com/v1/MossoCloudFS',
+            self.driver.connection.get_endpoint())
         self.driver.connection.cdn_request = False
 
     def test_list_containers(self):
@@ -163,6 +167,24 @@ class CloudFilesTests(unittest.TestCase):
         self.assertEqual(obj.size, 1160520)
         self.assertEqual(obj.container.name, 'test_container')
 
+    def test_list_container_objects_with_prefix(self):
+        CloudFilesMockHttp.type = 'EMPTY'
+        container = Container(
+            name='test_container', extra={}, driver=self.driver)
+        objects = self.driver.list_container_objects(container=container,
+                                                     ex_prefix='test_prefix1')
+        self.assertEqual(len(objects), 0)
+
+        CloudFilesMockHttp.type = None
+        objects = self.driver.list_container_objects(container=container,
+                                                     ex_prefix='test_prefix2')
+        self.assertEqual(len(objects), 4)
+
+        obj = [o for o in objects if o.name == 'foo test 1'][0]
+        self.assertEqual(obj.hash, '16265549b5bda64ecdaa5156de4c97cc')
+        self.assertEqual(obj.size, 1160520)
+        self.assertEqual(obj.container.name, 'test_container')
+
     def test_list_container_objects_iterator(self):
         CloudFilesMockHttp.type = 'ITERATOR'
         container = Container(
@@ -291,7 +313,7 @@ class CloudFilesTests(unittest.TestCase):
                                              destination_path=destination_path,
                                              overwrite_existing=False,
                                              delete_on_failure=True)
-        #self.assertTrue(result)
+        self.assertTrue(result)
 
     def test_download_object_invalid_file_size(self):
         CloudFilesMockRawResponse.type = 'INVALID_SIZE'
@@ -332,12 +354,13 @@ class CloudFilesTests(unittest.TestCase):
                      container=container, meta_data=None,
                      driver=CloudFilesStorageDriver)
 
-        stream = self.driver.download_object_as_stream(obj=obj, chunk_size=None)
+        stream = self.driver.download_object_as_stream(
+            obj=obj, chunk_size=None)
         self.assertTrue(hasattr(stream, '__iter__'))
 
     def test_upload_object_success(self):
         def upload_file(self, response, file_path, chunked=False,
-                     calculate_hash=True):
+                        calculate_hash=True):
             return True, 'hash343hhash89h932439jsaa89', 1000
 
         old_func = CloudFilesStorageDriver._upload_file
@@ -346,8 +369,9 @@ class CloudFilesTests(unittest.TestCase):
         container = Container(name='foo_bar_container', extra={}, driver=self)
         object_name = 'foo_test_upload'
         extra = {'meta_data': {'some-value': 'foobar'}}
-        obj = self.driver.upload_object(file_path=file_path, container=container,
-                                        extra=extra, object_name=object_name)
+        obj = self.driver.upload_object(
+            file_path=file_path, container=container,
+            extra=extra, object_name=object_name)
         self.assertEqual(obj.name, 'foo_test_upload')
         self.assertEqual(obj.size, 1000)
         self.assertTrue('some-value' in obj.meta_data)
@@ -355,7 +379,7 @@ class CloudFilesTests(unittest.TestCase):
 
     def test_upload_object_zero_size_object(self):
         def upload_file(self, response, file_path, chunked=False,
-                     calculate_hash=True):
+                        calculate_hash=True):
             return True, 'hash343hhash89h932439jsaa89', 0
 
         old_func = CloudFilesStorageDriver._upload_file
@@ -373,8 +397,9 @@ class CloudFilesTests(unittest.TestCase):
 
         self.driver.connection.request = func
         func.called = False
-        obj = self.driver.upload_object(file_path=file_path, container=container,
-                                        extra=extra, object_name=object_name)
+        obj = self.driver.upload_object(
+            file_path=file_path, container=container,
+            extra=extra, object_name=object_name)
         self.assertEqual(obj.name, 'empty')
         self.assertEqual(obj.size, 0)
         self.assertTrue(func.called)
@@ -383,7 +408,7 @@ class CloudFilesTests(unittest.TestCase):
 
     def test_upload_object_invalid_hash(self):
         def upload_file(self, response, file_path, chunked=False,
-                     calculate_hash=True):
+                        calculate_hash=True):
             return True, 'hash343hhash89h932439jsaa89', 1000
 
         CloudFilesMockRawResponse.type = 'INVALID_HASH'
@@ -414,17 +439,13 @@ class CloudFilesTests(unittest.TestCase):
         file_path = os.path.abspath(__file__)
         container = Container(name='foo_bar_container', extra={}, driver=self)
         object_name = 'foo_test_upload'
-        try:
-            self.driver.upload_object(file_path=file_path, container=container,
-                                      object_name=object_name)
-        except AttributeError:
-            pass
-        else:
-            self.fail(
-                'File content type not provided'
-                ' but an exception was not thrown')
-        finally:
-            libcloud.utils.files.guess_file_mime_type = old_func
+
+        obj = self.driver.upload_object(file_path=file_path, verify_hash=False,
+                                        container=container,
+                                        object_name=object_name)
+
+        self.assertEqual(obj.name, object_name)
+        libcloud.utils.files.guess_file_mime_type = old_func
 
     def test_upload_object_error(self):
         def dummy_content_type(name):
@@ -449,7 +470,8 @@ class CloudFilesTests(unittest.TestCase):
         except LibcloudError:
             pass
         else:
-            self.fail('Timeout while uploading but an exception was not thrown')
+            self.fail(
+                'Timeout while uploading but an exception was not thrown')
         finally:
             libcloud.utils.files.guess_file_mime_type = old_func1
             CloudFilesMockHttp.send = old_func2
@@ -522,6 +544,26 @@ class CloudFilesTests(unittest.TestCase):
         self.assertTrue('bytes_used' in meta_data)
         self.assertTrue('temp_url_key' in meta_data)
 
+    def test_ex_purge_object_from_cdn(self):
+        CloudFilesMockHttp.type = 'PURGE_SUCCESS'
+        container = Container(name='foo_bar_container', extra={},
+                              driver=self.driver)
+        obj = Object(name='object', size=1000, hash=None, extra={},
+                     container=container, meta_data=None,
+                     driver=self)
+
+        self.assertTrue(self.driver.ex_purge_object_from_cdn(obj=obj))
+
+    def test_ex_purge_object_from_cdn_with_email(self):
+        CloudFilesMockHttp.type = 'PURGE_SUCCESS_EMAIL'
+        container = Container(name='foo_bar_container', extra={},
+                              driver=self.driver)
+        obj = Object(name='object', size=1000, hash=None, extra={},
+                     container=container, meta_data=None,
+                     driver=self)
+        self.assertTrue(self.driver.ex_purge_object_from_cdn(obj=obj,
+                                                             email='test@test.com'))
+
     @mock.patch('os.path.getsize')
     def test_ex_multipart_upload_object_for_small_files(self, getsize_mock):
         getsize_mock.return_value = 0
@@ -533,8 +575,9 @@ class CloudFilesTests(unittest.TestCase):
         file_path = os.path.abspath(__file__)
         container = Container(name='foo_bar_container', extra={}, driver=self)
         object_name = 'foo_test_upload'
-        obj = self.driver.ex_multipart_upload_object(file_path=file_path, container=container,
-                                       object_name=object_name)
+        obj = self.driver.ex_multipart_upload_object(
+            file_path=file_path, container=container,
+            object_name=object_name)
         CloudFilesStorageDriver.upload_object = old_func
 
         self.assertTrue(mocked_upload_object.called)
@@ -545,7 +588,8 @@ class CloudFilesTests(unittest.TestCase):
         _upload_object_manifest = CloudFilesStorageDriver._upload_object_manifest
 
         mocked__upload_object_part = mock.Mock(return_value="test_part")
-        mocked__upload_object_manifest = mock.Mock(return_value="test_manifest")
+        mocked__upload_object_manifest = mock.Mock(
+            return_value="test_manifest")
 
         CloudFilesStorageDriver._upload_object_part = mocked__upload_object_part
         CloudFilesStorageDriver._upload_object_manifest = mocked__upload_object_manifest
@@ -555,8 +599,9 @@ class CloudFilesTests(unittest.TestCase):
         chunk_size = int(math.ceil(float(os.path.getsize(file_path)) / parts))
         container = Container(name='foo_bar_container', extra={}, driver=self)
         object_name = 'foo_test_upload'
-        self.driver.ex_multipart_upload_object(file_path=file_path, container=container,
-                                       object_name=object_name, chunk_size=chunk_size)
+        self.driver.ex_multipart_upload_object(
+            file_path=file_path, container=container,
+            object_name=object_name, chunk_size=chunk_size)
 
         CloudFilesStorageDriver._upload_object_part = _upload_object_part
         CloudFilesStorageDriver._upload_object_manifest = _upload_object_manifest
@@ -575,13 +620,13 @@ class CloudFilesTests(unittest.TestCase):
         container = Container(name='foo_bar_container', extra={}, driver=self)
 
         self.driver._upload_object_part(container, object_name,
-                part_number, None)
+                                        part_number, None)
 
         CloudFilesStorageDriver._put_object = _put_object
 
         func_kwargs = tuple(mocked__put_object.call_args)[1]
-        self.assertEquals(func_kwargs['object_name'], expected_name)
-        self.assertEquals(func_kwargs['container'], container)
+        self.assertEqual(func_kwargs['object_name'], expected_name)
+        self.assertEqual(func_kwargs['container'], container)
 
     def test__upload_object_manifest(self):
         hash_function = self.driver._get_hash_function()
@@ -589,8 +634,8 @@ class CloudFilesTests(unittest.TestCase):
         data_hash = hash_function.hexdigest()
 
         fake_response = type('CloudFilesResponse', (), {'headers':
-                {'etag': data_hash}
-            })
+                                                        {'etag': data_hash}
+                                                        })
 
         _request = self.driver.connection.request
         mocked_request = mock.Mock(return_value=fake_response)
@@ -605,14 +650,15 @@ class CloudFilesTests(unittest.TestCase):
 
         self.driver.connection.request = _request
 
-        self.assertEquals(func_args[0], "/" + container.name + "/" + object_name)
-        self.assertEquals(func_kwargs["headers"]["X-Object-Manifest"],
-                container.name + "/" + object_name + "/")
-        self.assertEquals(func_kwargs["method"], "PUT")
+        self.assertEqual(
+            func_args[0], "/" + container.name + "/" + object_name)
+        self.assertEqual(func_kwargs["headers"]["X-Object-Manifest"],
+                         container.name + "/" + object_name + "/")
+        self.assertEqual(func_kwargs["method"], "PUT")
 
     def test__upload_object_manifest_wrong_hash(self):
         fake_response = type('CloudFilesResponse', (), {'headers':
-            {'etag': '0000000'}})
+                                                        {'etag': '0000000'}})
 
         _request = self.driver.connection.request
         mocked_request = mock.Mock(return_value=fake_response)
@@ -621,7 +667,6 @@ class CloudFilesTests(unittest.TestCase):
         container = Container(name='foo_bar_container', extra={}, driver=self)
         object_name = "test_object"
 
-
         try:
             self.driver._upload_object_manifest(container, object_name)
         except ObjectHashMismatchError:
@@ -633,7 +678,7 @@ class CloudFilesTests(unittest.TestCase):
 
     def test_create_container_put_object_name_encoding(self):
         def upload_file(self, response, file_path, chunked=False,
-                     calculate_hash=True):
+                        calculate_hash=True):
             return True, 'hash343hhash89h932439jsaa89', 1000
 
         old_func = CloudFilesStorageDriver._upload_file
@@ -646,8 +691,9 @@ class CloudFilesTests(unittest.TestCase):
         container = self.driver.create_container(container_name=container_name)
         self.assertEqual(container.name, container_name)
 
-        obj = self.driver.upload_object(file_path=file_path, container=container,
-                                        object_name=object_name)
+        obj = self.driver.upload_object(
+            file_path=file_path, container=container,
+            object_name=object_name)
         self.assertEqual(obj.name, object_name)
         CloudFilesStorageDriver._upload_file = old_func
 
@@ -660,7 +706,7 @@ class CloudFilesTests(unittest.TestCase):
     def test_ex_set_error_page(self):
         container = Container(name='foo_bar_container', extra={}, driver=self)
         result = self.driver.ex_set_error_page(container=container,
-                                              file_name='error.html')
+                                               file_name='error.html')
         self.assertTrue(result)
 
     def test_ex_set_account_metadata_temp_url_key(self):
@@ -683,9 +729,11 @@ class CloudFilesTests(unittest.TestCase):
                                     "/v1/MossoCloudFS/foo_bar_container/foo_bar_object")
         sig = hmac.new(b('foo'), b(hmac_body), sha1).hexdigest()
         ret = self.driver.ex_get_object_temp_url(obj, 'GET')
-        temp_url = 'https://storage101.ord1.clouddrive.com/v1/MossoCloudFS/foo_bar_container/foo_bar_object?temp_url_expires=60&temp_url_sig=%s' % (sig)
+        temp_url = ('https://storage4.%s1.clouddrive.com/v1/MossoCloudFS/'
+                    'foo_bar_container/foo_bar_object?temp_url_expires=60&temp_url_sig=%s' %
+                    (self.region, sig))
 
-        self.assertEquals(''.join(sorted(ret)), ''.join(sorted(temp_url)))
+        self.assertEqual(''.join(sorted(ret)), ''.join(sorted(temp_url)))
 
     def test_ex_get_object_temp_url_no_key_raises_key_error(self):
         self.driver.ex_get_meta_data = mock.Mock()
@@ -697,7 +745,8 @@ class CloudFilesTests(unittest.TestCase):
         obj = Object(name='foo_bar_object', size=1000, hash=None, extra={},
                      container=container, meta_data=None,
                      driver=self)
-        self.assertRaises(KeyError, self.driver.ex_get_object_temp_url, obj, 'GET')
+        self.assertRaises(
+            KeyError, self.driver.ex_get_object_temp_url, obj, 'GET')
 
     def _remove_test_file(self):
         file_path = os.path.abspath(__file__) + '.temp'
@@ -708,27 +757,27 @@ class CloudFilesTests(unittest.TestCase):
             pass
 
 
+class CloudFilesDeprecatedUSTests(CloudFilesTests):
+    driver_klass = CloudFilesUSStorageDriver
+    region = 'ord'
+
+
+class CloudFilesDeprecatedUKTests(CloudFilesTests):
+    driver_klass = CloudFilesUKStorageDriver
+    region = 'lon'
+
+
 class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
 
     fixtures = StorageFileFixtures('cloudfiles')
-    auth_fixtures = OpenStackFixtures()
-    base_headers = { 'content-type': 'application/json; charset=UTF-8'}
+    base_headers = {'content-type': 'application/json; charset=UTF-8'}
 
     # fake auth token response
-    def _v1_0(self, method, url, body, headers):
+    def _v2_0_tokens(self, method, url, body, headers):
         headers = copy.deepcopy(self.base_headers)
-        headers.update({ 'x-server-management-url':
-                             'https://servers.api.rackspacecloud.com/v1.0/slug',
-                         'x-auth-token': 'FE011C19',
-                         'x-cdn-management-url':
-                             'https://cdn.clouddrive.com/v1/MossoCloudFS',
-                         'x-storage-token': 'FE011C19',
-                         'x-storage-url':
-                            'https://storage4.clouddrive.com/v1/MossoCloudFS'})
-        return (httplib.NO_CONTENT,
-                "",
-                headers,
-                httplib.responses[httplib.NO_CONTENT])
+        body = self.fixtures.load('_v2_0__auth.json')
+        return (httplib.OK, body, headers,
+                httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_MALFORMED_JSON(self, method, url, body, headers):
         # test_invalid_json_throws_exception
@@ -754,10 +803,10 @@ class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
             # get_meta_data
             body = self.fixtures.load('meta_data.json')
             status_code = httplib.NO_CONTENT
-            headers.update({ 'x-account-container-count': 10,
-                             'x-account-object-count': 400,
-                             'x-account-bytes-used': 1234567
-                           })
+            headers.update({'x-account-container-count': 10,
+                            'x-account-object-count': 400,
+                            'x-account-bytes-used': 1234567
+                            })
         elif method == 'POST':
             body = ''
             status_code = httplib.NO_CONTENT
@@ -796,29 +845,31 @@ class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
             # get_container
             body = self.fixtures.load('list_container_objects_empty.json')
             status_code = httplib.NO_CONTENT
-            headers.update({ 'x-container-object-count': 800,
-                             'x-container-bytes-used': 1234568
-                           })
+            headers.update({'x-container-object-count': 800,
+                            'x-container-bytes-used': 1234568
+                            })
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_test_container_ITERATOR(self, method, url, body, headers):
         headers = copy.deepcopy(self.base_headers)
         # list_container_objects
         if url.find('foo-test-3') != -1:
-            body = self.fixtures.load('list_container_objects_not_exhausted2.json')
+            body = self.fixtures.load(
+                'list_container_objects_not_exhausted2.json')
             status_code = httplib.OK
         elif url.find('foo-test-5') != -1:
             body = ''
             status_code = httplib.NO_CONTENT
         else:
             # First request
-            body = self.fixtures.load('list_container_objects_not_exhausted1.json')
+            body = self.fixtures.load(
+                'list_container_objects_not_exhausted1.json')
             status_code = httplib.OK
 
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_test_container_not_found(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
         # test_get_container_not_found
         if method == 'HEAD':
             body = ''
@@ -830,45 +881,44 @@ class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
                 httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_test_container_test_object(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
         headers = copy.deepcopy(self.base_headers)
         if method == 'HEAD':
             # get_object
             body = self.fixtures.load('list_container_objects_empty.json')
             status_code = httplib.NO_CONTENT
-            headers.update({ 'content-length': 555,
-                             'last-modified': 'Tue, 25 Jan 2011 22:01:49 GMT',
-                             'etag': '6b21c4a111ac178feacf9ec9d0c71f17',
-                             'x-object-meta-foo-bar': 'test 1',
-                             'x-object-meta-bar-foo': 'test 2',
-                             'content-type': 'application/zip'})
+            headers.update({'content-length': 555,
+                            'last-modified': 'Tue, 25 Jan 2011 22:01:49 GMT',
+                            'etag': '6b21c4a111ac178feacf9ec9d0c71f17',
+                            'x-object-meta-foo-bar': 'test 1',
+                            'x-object-meta-bar-foo': 'test 2',
+                            'content-type': 'application/zip'})
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_test_container__7E_test_object(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
         headers = copy.deepcopy(self.base_headers)
         if method == 'HEAD':
             # get_object_name_encoding
             body = self.fixtures.load('list_container_objects_empty.json')
             status_code = httplib.NO_CONTENT
-            headers.update({ 'content-length': 555,
-                             'last-modified': 'Tue, 25 Jan 2011 22:01:49 GMT',
-                             'etag': '6b21c4a111ac178feacf9ec9d0c71f17',
-                             'x-object-meta-foo-bar': 'test 1',
-                             'x-object-meta-bar-foo': 'test 2',
-                             'content-type': 'application/zip'})
+            headers.update({'content-length': 555,
+                            'last-modified': 'Tue, 25 Jan 2011 22:01:49 GMT',
+                            'etag': '6b21c4a111ac178feacf9ec9d0c71f17',
+                            'x-object-meta-foo-bar': 'test 1',
+                            'x-object-meta-bar-foo': 'test 2',
+                            'content-type': 'application/zip'})
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
-
     def _v1_MossoCloudFS_test_create_container(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
         # test_create_container_success
         headers = copy.deepcopy(self.base_headers)
         body = self.fixtures.load('list_container_objects_empty.json')
         headers = copy.deepcopy(self.base_headers)
-        headers.update({ 'content-length': 18,
-                         'date': 'Mon, 28 Feb 2011 07:52:57 GMT'
-                       })
+        headers.update({'content-length': 18,
+                        'date': 'Mon, 28 Feb 2011 07:52:57 GMT'
+                        })
         status_code = httplib.CREATED
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
@@ -882,18 +932,18 @@ class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
         headers = copy.deepcopy(self.base_headers)
         body = self.fixtures.load('list_container_objects_empty.json')
         headers = copy.deepcopy(self.base_headers)
-        headers.update({ 'content-length': 18,
-                         'date': 'Mon, 28 Feb 2011 07:52:57 GMT'
-                       })
+        headers.update({'content-length': 18,
+                        'date': 'Mon, 28 Feb 2011 07:52:57 GMT'
+                        })
         status_code = httplib.CREATED
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_test_create_container_ALREADY_EXISTS(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
         # test_create_container_already_exists
         headers = copy.deepcopy(self.base_headers)
         body = self.fixtures.load('list_container_objects_empty.json')
-        headers.update({ 'content-type': 'text/plain' })
+        headers.update({'content-type': 'text/plain'})
         status_code = httplib.ACCEPTED
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
@@ -910,8 +960,27 @@ class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
             status_code = httplib.ACCEPTED
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
+    def _v1_MossoCloudFS_foo_bar_container_object_PURGE_SUCCESS(
+            self, method, url, body, headers):
+
+        if method == 'DELETE':
+            # test_ex_purge_from_cdn
+            headers = self.base_headers
+            status_code = httplib.NO_CONTENT
+        return (status_code, body, headers, httplib.responses[httplib.OK])
+
+    def _v1_MossoCloudFS_foo_bar_container_object_PURGE_SUCCESS_EMAIL(
+            self, method, url, body, headers):
+
+        if method == 'DELETE':
+            # test_ex_purge_from_cdn_with_email
+            self.assertEqual(headers['X-Purge-Email'], 'test@test.com')
+            headers = self.base_headers
+            status_code = httplib.NO_CONTENT
+        return (status_code, body, headers, httplib.responses[httplib.OK])
+
     def _v1_MossoCloudFS_foo_bar_container_NOT_FOUND(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
 
         if method == 'DELETE':
             # test_delete_container_not_found
@@ -921,7 +990,7 @@ class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_foo_bar_container_NOT_EMPTY(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
 
         if method == 'DELETE':
             # test_delete_container_not_empty
@@ -931,7 +1000,7 @@ class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_foo_bar_container_foo_bar_object(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
 
         if method == 'DELETE':
             # test_delete_object_success
@@ -941,7 +1010,7 @@ class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_foo_bar_container_foo_bar_object_NOT_FOUND(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
 
         if method == 'DELETE':
             # test_delete_object_success
@@ -951,18 +1020,14 @@ class CloudFilesMockHttp(StorageMockHttp, MockHttpTestCase):
 
         return (status_code, body, headers, httplib.responses[httplib.OK])
 
-    def _v1_1_auth(self, method, url, body, headers):
-        body = self.auth_fixtures.load('_v1_1__auth.json')
-        return (httplib.OK, body, {'content-type': 'application/json; charset=UTF-8'}, httplib.responses[httplib.OK])
-
 
 class CloudFilesMockRawResponse(MockRawResponse):
 
     fixtures = StorageFileFixtures('cloudfiles')
-    base_headers = { 'content-type': 'application/json; charset=UTF-8'}
+    base_headers = {'content-type': 'application/json; charset=UTF-8'}
 
     def _v1_MossoCloudFS_foo_bar_container_foo_test_upload(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
         # test_object_upload_success
 
         body = ''
@@ -976,14 +1041,13 @@ class CloudFilesMockRawResponse(MockRawResponse):
         # test_create_container_put_object_name_encoding
         # Verify that the name is properly url encoded
         object_name = 'm@obj€ct'
-        encoded_object_name = urlquote(object_name)
+        urlquote(object_name)
 
         headers = copy.deepcopy(self.base_headers)
         body = ''
         headers['etag'] = 'hash343hhash89h932439jsaa89'
         return (httplib.CREATED, body, headers, httplib.responses[httplib.OK])
 
-
     def _v1_MossoCloudFS_foo_bar_container_empty(self, method, url, body,
                                                  headers):
         # test_upload_object_zero_size_object
@@ -994,7 +1058,7 @@ class CloudFilesMockRawResponse(MockRawResponse):
         return (httplib.CREATED, body, headers, httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_foo_bar_container_foo_test_upload_INVALID_HASH(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
         # test_object_upload_invalid_hash
         body = ''
         headers = {}
@@ -1004,34 +1068,32 @@ class CloudFilesMockRawResponse(MockRawResponse):
                 httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_foo_bar_container_foo_bar_object(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
 
         # test_download_object_success
-        body = 'test'
-        self._data = self._generate_random_data(1000)
+        body = self._generate_random_data(1000)
         return (httplib.OK,
                 body,
                 self.base_headers,
                 httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_foo_bar_container_foo_bar_object_INVALID_SIZE(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
         # test_download_object_invalid_file_size
-        body = 'test'
-        self._data = self._generate_random_data(100)
+        body = self._generate_random_data(100)
         return (httplib.OK, body,
                 self.base_headers,
                 httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_foo_bar_container_foo_bar_object_NOT_FOUND(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
         body = ''
         return (httplib.NOT_FOUND, body,
                 self.base_headers,
                 httplib.responses[httplib.OK])
 
     def _v1_MossoCloudFS_foo_bar_container_foo_test_stream_data(
-        self, method, url, body, headers):
+            self, method, url, body, headers):
 
         # test_upload_object_via_stream_success
         headers = {}
